aboutsummaryrefslogtreecommitdiff
path: root/core.go
diff options
context:
space:
mode:
Diffstat (limited to 'core.go')
-rw-r--r--core.go9
1 files changed, 6 insertions, 3 deletions
diff --git a/core.go b/core.go
index 5001261..e5ab4a4 100644
--- a/core.go
+++ b/core.go
@@ -100,12 +100,15 @@ func (api *API) requestHandler(resource interface{}) http.HandlerFunc {
}
// AddResource adds a new resource to an API. The API will route
-// requests to the matching HTTP method on the resource.
-func (api *API) AddResource(resource interface{}, path string) {
+// requests that match one of the given paths to the matching HTTP
+// method on the resource.
+func (api *API) AddResource(resource interface{}, paths ...string) {
if api.mux == nil {
api.mux = http.NewServeMux()
}
- api.mux.HandleFunc(path, api.requestHandler(resource))
+ for _, path := range paths {
+ api.mux.HandleFunc(path, api.requestHandler(resource))
+ }
}
// Start causes the API to begin serving requests on the given port.
bgstack15